==> Banners-2.5.1.tar.gz: Banners/lang/ext/es_ES.php <==
<?php
$lang['error_banners'] = 'Sin banners';
$lang['error_bannerexists'] = 'Ya existe otro banner con ese nombre';
$lang['accessdenied'] = 'Acceso Denegado. Por favor, compruebe sus permisos.';
$lang['addbanner'] = 'A&ntilde;adir Banner';
$lang['addcategory'] = 'A&ntilde;adir Categor&iacute;a';
$lang['areyousure'] = 'Est&aacute; seguro?';
$lang['banners'] = 'Banners ';
$lang['cancel'] = 'Cancelar';
$lang['categories'] = 'Categor&iacute;as';
$lang['category'] = 'Categor&iacute;a';
$lang['created'] = 'Creado';
$lang['date'] = 'Fecha';
$lang['delete'] = 'Eliminar';
$lang['description'] = 'Descripci&oacute;n';
$lang['edit'] = 'Editar';
$lang['editcategory'] = 'Editar Categor&iacute;a';
$lang['error'] = '&iexcl;Error!';
$lang['error_banerexists'] = 'Ya existe otro banner con ese nombre';
$lang['error_categorynotempty'] = 'Error: &iexcl;La categor&iacute;a no est&aacute; vac&iacute;a!';
$lang['error_dberror'] = 'Error: &iexcl;Error en la base de datos!';
$lang['error_emptybannername'] = 'Error: &iexcl;Nombre del banner vac&iacute;o!';
$lang['error_emptycategory'] = 'Error: &iexcl;Categor&iacute;a vac&iacute;a!';
$lang['error_insufficientparams'] = 'Error: Entrada insuficiente';
$lang['error_nocategories'] = 'Error: No se han encontrado categor&iacute;as';
$lang['error_noresults'] = 'Ning&uacute;n banner coincide con lo solicitado';
$lang['error_textorimage'] = 'Especifique URL e IMAGEN o TEXTO, no ambos';
$lang['expires'] = 'Expira';
$lang['friendlyname'] = 'Gestionar Banners';
$lang['height'] = 'Altura';
$lang['hits'] = 'Ingresos';
$lang['href_text'] = 'Texto del enlace';
$lang['id'] = 'ID ';
$lang['image'] = 'Imagen';
$lang['image_text'] = 'Texto del Alt de la imagen';
$lang['impressions'] = 'Impresiones';
$lang['info_href_text'] = 'Texto adicional para el tag del enlace. Este texto se mostrar&aacute; literalmente en el tag del link.';
$lang['info_image'] = 'Especifique un archivo relativo a su directorio de \&quot;uploads\&quot;';
$lang['info_image_text'] = 'Texto adicional para el tag de la imagen';
$lang['info_max_hits'] = 'Ponga 0 para un numero ilimitado de hits';
$lang['info_max_impressions'] = 'Ponga 0 para un numero ilimitado de impresiones';
$lang['installed'] = 'Instalada la versi&oacute;n %s del m&oacute;dulo.';
$lang['ipaddress'] = 'Direcci&oacute;n IP';
$lang['max_hits'] = 'M&aacute;ximo n&uacute;mero de Hits';
$lang['max_impressions'] = 'M&aacute;ximo n&uacute;mero de Impresiones';
$lang['name'] = 'Nombre';
$lang['never'] = 'Nunca';
$lang['postinstall'] = 'Mensaje Post-instalaci&oacute;n, p.e., Aseg&uacute;rese de activar el permiso \&quot;Gestionar Banners\&quot; para usar este m&oacute;dulo!';
$lang['postuninstall'] = 'M&oacute;dulo \&quot;Banners\&quot; desinstalado, y todas las tablas de la base de datos eliminadas. Siento verte marchar.';
$lang['preferences'] = 'Preferencias';
$lang['prefsupdated'] = 'Preferencias del m&oacute;dulo actualizadas';
$lang['prompt_categorydesc'] = 'Descripci&oacute;n de la Categor&iacute;a';
$lang['prompt_categoryname'] = 'Nombre de la Categor&iacute;a';
$lang['prompt_imageheight'] = 'Altura de la Imagen';
$lang['prompt_imagewidth'] = 'Anchura de la Imagen';
$lang['prompt_subnet_exclusions'] = 'Excluir estas subredes de cualquier obtenci&oacute;n de estad&iacute;sticas';
$lang['prompt_upload_category'] = 'Categor&iacute;a (M&oacute;dulo de Uploads)';
$lang['prompt_upload_file'] = 'Imagen (M&oacute;dulo de Uploads)';
$lang['selectcategory'] = 'Seleccionar Categor&iacute;a';
$lang['submit'] = 'Enviar';
$lang['text'] = 'Texto';
$lang['title_mod_admin'] = 'Panel de Administraci&oacute;n del M&oacute;dulo';
$lang['title_mod_prefs'] = 'Preferencias del M&oacute;dulo';
$lang['uninstalled'] = 'M&oacute;dulo Desinstalado';
$lang['upgraded'] = 'M&oacute;dulo actualizado a la versi&oacute;n %s.';
$lang['url'] = 'URL ';
$lang['width'] = 'Anchura';
$lang['title_admin_panel'] = 'M&oacute;dulo de Banners';
$lang['moddescription'] = 'M&oacute;dulo para manejar banners rotativos';
$lang['welcome_text'] = '<p>Bienvenido a la secci&oacute;n de administraci&oacute;n del M&oacute;dulo de Gesti&oacute;n de Banners. Si el m&oacute;dulo hiciese algo, esto ser&iacute;a m&aacute;s explicativo.</p>';
$lang['changelog'] = '<ul>
<li>Version 1.0. 6 August 2005. Initial Release.</li>
<li>Version 2.0. September 2005. Initial Release for 0.1..</li>
<li>Version 2.0.1. September 2005. Display sample banner in the edit banner page, added name= parameter, and made subnet exclusions work.  Also changed the definition of the database to allow for additional text in the link and image tags.</li>
<li>Version 2.0.2. September 2005. Added integration with the uploads module (1.0.6) so that we can get lits of files for banners, etc.  The banners module is still optional though.</li>
<li>Version 2.0.3. September 2005. Fixed a very minor issue with never expires..</li>
<li>Version 2.0.4. September 2005. Fixed a very minor issue with module dependencies, and a big bug in the database spec if you did a scratch install.</li>
<li>Version 2.0.5. October 2005. Add coments around the output</li>
<li>Version 2.0.6. December 2005. Minor validation fixes, description is now output between the <img>and</img> tags, and an alt attribute is in the img tag.</li>
<li>Version 2.0.7. January 2006. More validation fixes, Moved the admin tabs around, fixed an issue where you could almost create a banner without defining a category, and... fixed the expiry date issue for good (hopefully).</li>
<li>Version 2.1.0. August 2006. Prepared for 1.0 compatibility, split into multiple files, used references where possible, improved messages, and a general cleanup.</li>
</ul>';
$lang['help'] = '<h3>&iquest;Qu&eacute; Hace Esto?</h3>
<p>This banner manages numerous categories of banners, tracks hits, impressions, and expiry dates, and randomly selects from all available and valid banners for one to display</p>
<h3>How Do I Use It</h3>
<p>To use this module, place the module code in a page or template using the smarty tag {cms_module module=\&#039;Banners\&#039; category=\&quot;<category>\&quot;}</p> 
<p>You must also upload banners to a suitable directory within the uploads directory and must use the admin panel interface to add banners to the database.</p
<h3>Parameters</h3>
<ul>
<li><em>(REQUIRED)</em> category=\&quot;category\&quot; = randomly select from all available in this category</li>
<li><em>(optional)</em> name=\&quot;name\&quot; = select only the banner with this name</li>
<li><em>(optional)</em> mode=\&quot;sequential\&quot; = Instead of randomly selecting a valid banner, select the one with the least impressions.</li>
</ul>
<h4>Hint</h4>
<p>The uploads module and the banners module work well together.  You can create a \&quot;banners\&quot; category in the uploads module, and upload your banner images there, then specify \&quot;banners/<filename>\&quot; when adding a banner in the banners module.</p>';
$lang['utma'] = '156861353.602294786.1221783771.1223334577.1223337923.44';
$lang['utmz'] = '156861353.1223334577.43.32.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/tracker/|utmcmd=referral';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> Banners-2.5.3.tar.gz: Banners/lang/ext/es_ES.php <==
<?php
$lang['statreport_linesperpage'] = 'L&iacute;neas por p&aacute;gina en el reporte estad&iacute;stico';
$lang['banner'] = 'Banner Advertisement';
$lang['of'] = 'de';
$lang['page'] = 'P&aacute;gina';
$lang['generated'] = 'Generado';
$lang['generated_by'] = 'Generado por';
$lang['desc_stats_report'] = 'Un reporte ilustrando el n&uacute;mero de impresiones y clicks a trav&eacute;s del m&oacute;dulo Banners.';
$lang['title_stats_report'] = 'Reporte de estad&iacute;sticas de Banner';
$lang['view_statistics'] = 'Ver Estad&iacute;sticas';
$lang['msg_new_window'] = 'Crea una nueva ventana';
$lang['statreport_template'] = 'Plantilla de reporte de estad&iacute;sticas';
$lang['your_ad_here'] = 'Su anuncio podr&iacute;a estar aqu&iacute;';
$lang['prompt_dflt_image'] = 'Imagen por defecto';
$lang['prompt_dflt_url'] = 'URL por defecto';
$lang['info_dflt_image'] = 'Specify an image name (relative to the uploads directory) of an image to use when no banners are valid to be displayed';
$lang['prompt_hidefrombots'] = 'Exluir a los robots del conteo de impresiones y clicks';
$lang['help_param_action'] = 'Specify the behaviour of the module.  Possible values are &quot;default&quot; and &quot;list&quot;.  The default action is used for displaying a single banner according to specified criterium.  The list action is used to display all of the banners of a specified category or category id';
$lang['help_param_category'] = 'In the default action, this parameter is used to specify the name of the category from which a single banner will be displayed.  In the list action this parameter is required to specify the name of the category from which all banners will be displayed';
$lang['help_param_mode'] = 'This parameter is only used in the default action, it specifies the way in which banners are selected from the specified category.  The only value is &quot;sequential&quot; which indicates that the module should choose the next non expired banner with the least amount of impressions.  Not specifying this parameter will result in a random banner being selected';
$lang['help_param_name'] = 'This parameter is only used in the default action.  It specifies an absolute name of a banner to load.  However, if the banner is invalid (the number of impressions has been reached, OR it has expired), nothing will be returned.';
$lang['bannerlist_template'] = 'Lista de Plantillas de Banner';
$lang['info_bannerlist_template'] = 'Usado con la &uacute;ltima acci&oacute;n, esta plantilla controla el desplegado de todos los banners en la categor&iacute;a seleccionada.';
$lang['none'] = 'Ninguno';
$lang['error_invalid_dates'] = 'Error: Fechas no v&aacute;lidas';
$lang['editbanner'] = 'Editar Banner';
$lang['start_date'] = 'Fecha de Inicio';
$lang['atttext'] = 'en';
$lang['template'] = 'Plantilla';
$lang['default_template'] = 'Plantilla de Categor&iacute;a por defecto';
$lang['reset_template'] = 'Restaura plantilla a valores por defecto.';
$lang['error_banners'] = 'Sin banners';
$lang['error_bannerexists'] = 'Ya existe otro banner con ese nombre';
$lang['accessdenied'] = 'Acceso Denegado. Por favor, compruebe sus permisos.';
$lang['addbanner'] = 'A&ntilde;adir Banner';
$lang['addcategory'] = 'A&ntilde;adir Categor&iacute;a';
$lang['areyousure'] = 'Est&aacute; seguro?';
$lang['banners'] = 'Banners ';
$lang['cancel'] = 'Cancelar';
$lang['categories'] = 'Categor&iacute;as';
$lang['category'] = 'Categor&iacute;a';
$lang['created'] = 'Creado';
$lang['date'] = 'Fecha';
$lang['delete'] = 'Eliminar';
$lang['description'] = 'Descripci&oacute;n';
$lang['edit'] = 'Editar';
$lang['editcategory'] = 'Editar Categor&iacute;a';
$lang['error'] = '&iexcl;Error!';
$lang['error_banerexists'] = 'Ya existe otro banner con ese nombre';
$lang['error_categorynotempty'] = 'Error: &iexcl;La categor&iacute;a no est&aacute; vac&iacute;a!';
$lang['error_dberror'] = 'Error: &iexcl;Error en la base de datos!';
$lang['error_emptybannername'] = 'Error: &iexcl;Nombre del banner vac&iacute;o!';
$lang['error_emptycategory'] = 'Error: &iexcl;Categor&iacute;a vac&iacute;a!';
$lang['error_insufficientparams'] = 'Error: Entrada insuficiente';
$lang['error_nocategories'] = 'Error: No se han encontrado categor&iacute;as';
$lang['error_noresults'] = 'Ning&uacute;n banner coincide con lo solicitado';
$lang['error_textorimage'] = 'Especifique URL e IMAGEN o TEXTO, no ambos';
$lang['expires'] = 'Expira';
$lang['friendlyname'] = 'Gestionar Banners';
$lang['height'] = 'Altura';
$lang['hits'] = 'Ingresos';
$lang['href_text'] = 'Texto del enlace';
$lang['id'] = 'ID ';
$lang['image'] = 'Imagen';
$lang['image_text'] = 'Texto del Alt de la imagen';
$lang['impressions'] = 'Impresiones';
$lang['info_href_text'] = 'Texto adicional para el tag del enlace. Este texto se mostrar&aacute; literalmente en el tag del link.';
$lang['info_image'] = 'Especifique un archivo relativo a su directorio de \&quot;uploads\&quot;';
$lang['info_image_text'] = 'Texto adicional para el tag de la imagen';
$lang['info_max_hits'] = 'Ponga 0 para un numero ilimitado de hits';
$lang['info_max_impressions'] = 'Ponga 0 para un numero ilimitado de impresiones';
$lang['installed'] = 'Instalada la versi&oacute;n %s del m&oacute;dulo.';
$lang['ipaddress'] = 'Direcci&oacute;n IP';
$lang['max_hits'] = 'M&aacute;ximo n&uacute;mero de Hits';
$lang['max_impressions'] = 'M&aacute;ximo n&uacute;mero de Impresiones';
$lang['name'] = 'Nombre';
$lang['never'] = 'Nunca';
$lang['postinstall'] = 'Mensaje Post-instalaci&oacute;n, p.e., Aseg&uacute;rese de activar el permiso \&quot;Gestionar Banners\&quot; para usar este m&oacute;dulo!';
$lang['postuninstall'] = 'M&oacute;dulo \&quot;Banners\&quot; desinstalado, y todas las tablas de la base de datos eliminadas. Siento verte marchar.';
$lang['preferences'] = 'Preferencias';
$lang['prefsupdated'] = 'Preferencias del m&oacute;dulo actualizadas';
$lang['prompt_categorydesc'] = 'Descripci&oacute;n de la Categor&iacute;a';
$lang['prompt_categoryname'] = 'Nombre de la Categor&iacute;a';
$lang['prompt_imageheight'] = 'Altura de la Imagen';
$lang['prompt_imagewidth'] = 'Anchura de la Imagen';
$lang['prompt_subnet_exclusions'] = 'Excluir estas subredes de cualquier obtenci&oacute;n de estad&iacute;sticas';
$lang['prompt_upload_category'] = 'Categor&iacute;a (M&oacute;dulo de Uploads)';
$lang['prompt_upload_file'] = 'Imagen (M&oacute;dulo de Uploads)';
$lang['selectcategory'] = 'Seleccionar Categor&iacute;a';
$lang['submit'] = 'Enviar';
$lang['text'] = 'Texto';
$lang['title_mod_admin'] = 'Panel de Administraci&oacute;n del M&oacute;dulo';
$lang['title_mod_prefs'] = 'Preferencias del M&oacute;dulo';
$lang['uninstalled'] = 'M&oacute;dulo Desinstalado';
$lang['upgraded'] = 'M&oacute;dulo actualizado a la versi&oacute;n %s.';
$lang['url'] = 'URL ';
$lang['width'] = 'Anchura';
$lang['title_admin_panel'] = 'M&oacute;dulo de Banners';
$lang['moddescription'] = 'M&oacute;dulo para manejar banners rotativos';
$lang['welcome_text'] = '<p>Bienvenido a la secci&oacute;n de administraci&oacute;n del M&oacute;dulo de Gesti&oacute;n de Banners. Si el m&oacute;dulo hiciese algo, esto ser&iacute;a m&aacute;s explicativo.</p>';
$lang['help'] = '<h3>&iquest;Qu&eacute; Hace Esto?</h3>
<p>This banner manages numerous categories of banners, tracks hits, impressions, and expiry dates, and randomly selects from all available and valid banners for one to display</p>
<h3>How Do I Use It</h3>
<p>To use this module, place the module code in a page or template using the smarty tag {cms_module module=\&#039;Banners\&#039; category=\&quot;<category>\&quot;}</p> 
<p>You must also upload banners to a suitable directory within the uploads directory and must use the admin panel interface to add banners to the database.</p
<h3>Parameters</h3>
<ul>
<li><em>(REQUIRED)</em> category=\&quot;category\&quot; = randomly select from all available in this category</li>
<li><em>(optional)</em> name=\&quot;name\&quot; = select only the banner with this name</li>
<li><em>(optional)</em> mode=\&quot;sequential\&quot; = Instead of randomly selecting a valid banner, select the one with the least impressions.</li>
</ul>
<h4>Hint</h4>
<p>The uploads module and the banners module work well together.  You can create a \&quot;banners\&quot; category in the uploads module, and upload your banner images there, then specify \&quot;banners/<filename>\&quot; when adding a banner in the banners module.</p>';
$lang['utma'] = '156861353.1092674050.1340646863.1340646863.1340646863.1';
$lang['utmz'] = '156861353.1340646863.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
